@@ -32,7 +32,7 @@ import platform
 import re
 import sys
 from site import USER_BASE
-from typing import Iterable, Optional, Sequence
+from typing import Any, Iterable, Optional, Sequence, Union
 
 # XXX: we *also* need pytz even though dateutil also ships time zone
 # info. pytz has the *list* of all time zones, which dateutil doesn't
@@ -112,10 +112,17 @@ class NegateAction(argparse.Action):
         )
         super(NegateAction, self).__init__(option_strings, *args, nargs=0, **kwargs)
 
-    def __call__(self, parser, ns, values, option):
+    def __call__(
+        self,
+        parser: argparse.ArgumentParser,
+        ns: argparse.Namespace,
+        values: Optional[Union[str, Sequence[Any]]],
+        option_string: Optional[str] = None,
+    ) -> None:
         """set the truth value depending on whether
         it starts with the negative form"""
-        setattr(ns, self.dest, not option.startswith(self.negative))
+        if option_string:
+            setattr(ns, self.dest, not option_string.startswith(self.negative))
 
 
 class ConfigAction(argparse._StoreAction):
@@ -133,21 +140,30 @@ class ConfigAction(argparse._StoreAction):
         kwargs["nargs"] = 1
         super().__init__(*args, **kwargs)
 
-    def __call__(self, parser, ns, values, option):  # type: ignore[no-untyped-def]
+    def __call__(
+        self,
+        parser: argparse.ArgumentParser,
+        ns: argparse.Namespace,
+        values: Optional[Union[str, Sequence[Any]]],
+        option_string: Optional[str] = None,
+    ) -> None:
         """change defaults for the namespace, still allows overriding
         from commandline options"""
-        for path in values:
-            try:
-                # XXX: this is probably the bit that fails with
-                # subparsers and groups
-                parser.set_defaults(**self.parse_config(path))
-            except FileNotFoundError as e:
-                logging.debug("config file %s not found: %s", path, e)
-            else:
-                # stop processing once we find a valid configuration
-                # file
-                break
-        super().__call__(parser, ns, values, option)
+        if values:
+            if not isinstance(values, Sequence):
+                values = [values]
+            for path in values:
+                try:
+                    # XXX: this is probably the bit that fails with
+                    # subparsers and groups
+                    parser.set_defaults(**self.parse_config(path))
+                except FileNotFoundError as e:
+                    logging.debug("config file %s not found: %s", path, e)
+                else:
+                    # stop processing once we find a valid configuration
+                    # file
+                    break
+        super().__call__(parser, ns, values, option_string)
 
     def parse_config(self, path: str) -> dict:  # type: ignore[type-arg]
         """abstract implementation of config file parsing, should be overridden in subclasses"""
@@ -354,11 +370,20 @@ class LoggingAction(argparse.Action):
             kwargs["nargs"] = 0
         super().__init__(*args, **kwargs)
 
-    def __call__(self, parser, ns, values, option):  # type: ignore[no-untyped-def]
+    def __call__(
+        self,
+        parser: argparse.ArgumentParser,
+        ns: argparse.Namespace,
+        values: Optional[Union[str, Sequence[Any]]],
+        option_string: Optional[str] = None,
+    ) -> None:
         """if const was specified it means argument-less parameters"""
         if self.const:
             logging.getLogger("").setLevel(self.const)
         else:
+            values = str(values)
+            if values not in logging.getLevelNamesMapping().keys():
+                parser.error("invalid logging level: %s" % values)
             logging.getLogger("").setLevel(values)
         # cargo-culted from _StoreConstAction
         setattr(ns, self.dest, self.const or values)
@@ -473,6 +498,18 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             action=NegateAction,
             help="hide/show the actual table [default: %(default)s]",
         )
+        group.add_argument(
+            "--no-time-details",
+            "--time-details",
+            dest="time_details",
+            action=NegateAction,
+            help="show/hide trailing time details like UTC, local, and equivalent times [default: %(default)s]",
+        )
+        group.add_argument(
+            "--all-formats",
+            action="store_true",
+            help="show a sample of *all* table formats",
+        )
         group.add_argument(
             "-f",
             "--format",
@@ -552,6 +589,11 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             self.error("date specified as an argument an option, aborting")
         if ns.datelist and not ns.date:
             ns.date = " ".join(ns.datelist)
+        if not ns.time_details and not ns.table:
+            logging.warning(
+                "select --table or --time-details otherwise undertime does nothing, falling back to --time-details"
+            )
+            ns.time_details = True
         for h in ("start", "end"):
             if getattr(ns, h) < 0:
                 # this should probably never happen as it's probably
@@ -889,42 +931,36 @@ def main(args):
             overlap_show=args.overlap,
             truncate=args.truncate,
         )
-        # reproduce the terminaltables DoubleTable output in tabulate:
-        # https://github.com/cmck/python-tabulate/issues/1
-        if args.format == "fancy_grid_nogap":
-            args.format = tabulate.TableFormat(
-                lineabove=tabulate.Line("╔", "═", "╤", "╗"),
-                linebelowheader=tabulate.Line("╠", "═", "╪", "╣"),
-                linebetweenrows=None,
-                linebelow=tabulate.Line("╚", "═", "╧", "╝"),
-                headerrow=tabulate.DataRow("║", "│", "║"),
-                datarow=tabulate.DataRow("║", "│", "║"),
-                padding=1,
-                with_header_hide=None,
-            )
-        table = tabulate.tabulate(
-            rows, tablefmt=args.format, headers="firstrow", stralign="center"
-        )
-        print(table)
-    times = []
-    for zone in timezones:
-        other_zone_day = "{0:%Y-%m-%d}".format(then_local.astimezone(tz=zone))
-        local_zone_day = "{0:%Y-%m-%d}".format(then_local)
-        if local_zone_day != other_zone_day:
-            logging.debug(
-                "different day: local (%s) is %s other (%s) is %s",
-                default_zone,
-                local_zone_day,
-                zone,
-                other_zone_day,
-            )
-            ts = "{0:%Y-%m-%d %H:%M} {1}".format(then_local.astimezone(tz=zone), zone)
+        if args.all_formats:
+            for fmt in tabulate.tabulate_formats + ["fancy_grid_nogap"]:
+                print("format:", fmt)
+                print(format_table(rows, fmt))
         else:
-            ts = "{0:%H:%M} {1}".format(then_local.astimezone(tz=zone).timetz(), zone)
-        times.append(ts)
-    print("UTC time: {}".format(then_utc))
-    print("local time: {}".format(then_local))
-    print("equivalent to: " + ", ".join(times))
+            print(format_table(rows, args.format))
+    if args.time_details:
+        times = []
+        for zone in timezones:
+            other_zone_day = "{0:%Y-%m-%d}".format(then_local.astimezone(tz=zone))
+            local_zone_day = "{0:%Y-%m-%d}".format(then_local)
+            if local_zone_day != other_zone_day:
+                logging.debug(
+                    "different day: local (%s) is %s other (%s) is %s",
+                    default_zone,
+                    local_zone_day,
+                    zone,
+                    other_zone_day,
+                )
+                ts = "{0:%Y-%m-%d %H:%M} {1}".format(
+                    then_local.astimezone(tz=zone), zone
+                )
+            else:
+                ts = "{0:%H:%M} {1}".format(
+                    then_local.astimezone(tz=zone).timetz(), zone
+                )
+            times.append(ts)
+        print("UTC time: {}".format(then_utc))
+        print("local time: {}".format(then_local))
+        print("equivalent to: " + ", ".join(times))
 
 
 def guess_zone(zone):
@@ -1060,6 +1096,23 @@ def compute_table(
     return rows
 
 
+def format_table(rows, fmt):
+    # reproduce the terminaltables DoubleTable output in tabulate:
+    # https://github.com/cmck/python-tabulate/issues/1
+    if fmt == "fancy_grid_nogap":
+        fmt = tabulate.TableFormat(
+            lineabove=tabulate.Line("╔", "═", "╤", "╗"),
+            linebelowheader=tabulate.Line("╠", "═", "╪", "╣"),
+            linebetweenrows=None,
+            linebelow=tabulate.Line("╚", "═", "╧", "╝"),
+            headerrow=tabulate.DataRow("║", "│", "║"),
+            datarow=tabulate.DataRow("║", "│", "║"),
+            padding=1,
+            with_header_hide=None,
+        )
+    return tabulate.tabulate(rows, tablefmt=fmt, headers="firstrow", stralign="center")
+
+
 def sysinfo(callback=logging.debug):  # pragma: nocover
     """dump a lot of system information to help with support
 
